"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def delete(hub, ctx, name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes all versions of the intent, including the $LATEST version. To delete a specific version of the intent, use the DeleteIntentVersion operation.  You can delete a version of an intent only if it is not referenced. To delete an intent that is referred to in one or more bots (see how-it-works), you must remove those references first.    If you get the ResourceInUseException exception, it provides an example reference that shows where the intent is referenced. To remove the reference to the intent, either update the bot or delete it. If you get the same exception when you attempt to delete the intent again, repeat until the intent has no references and the call to DeleteIntent is successful.    This operation requires permission for the lex:DeleteIntent action.

    Args:
        name(str): The name of the intent. The name is case sensitive. .
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lex_model.intent.init.delete(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lex_model.intent.init.delete name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lex-models",
        operation="delete_intent",
        op_kwargs={"name": name},
    )


async def get(hub, ctx, name: str, version: str) -> Dict:
    r"""
    **Autogenerated function**

     Returns information about an intent. In addition to the intent name, you must specify the intent version.   This operation requires permissions to perform the lex:GetIntent action.

    Args:
        name(str): The name of the intent. The name is case sensitive. .
        version(str): The version of the intent.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lex_model.intent.init.get(ctx, name=value, version=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lex_model.intent.init.get name=value, version=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lex-models",
        operation="get_intent",
        op_kwargs={"name": name, "version": version},
    )


async def get_all(
    hub, ctx, next_token: str = None, max_results: int = None, name_contains: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns intent information as follows:    If you specify the nameContains field, returns the $LATEST version of all intents that contain the specified string.    If you don't specify the nameContains field, returns information about the $LATEST version of all intents.     The operation requires permission for the lex:GetIntents action.

    Args:
        next_token(str, optional): A pagination token that fetches the next page of intents. If the response to this API call is truncated, Amazon Lex returns a pagination token in the response. To fetch the next page of intents, specify the pagination token in the next request. . Defaults to None.
        max_results(int, optional): The maximum number of intents to return in the response. The default is 10. Defaults to None.
        name_contains(str, optional): Substring to match in intent names. An intent will be returned if any part of its name matches the substring. For example, "xyz" matches both "xyzabc" and "abcxyz.". Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lex_model.intent.init.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lex_model.intent.init.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lex-models",
        operation="get_intents",
        op_kwargs={
            "nextToken": next_token,
            "maxResults": max_results,
            "nameContains": name_contains,
        },
    )


async def put(
    hub,
    ctx,
    name: str,
    description: str = None,
    slots: List = None,
    sample_utterances: List = None,
    confirmation_prompt: Dict = None,
    rejection_statement: Dict = None,
    follow_up_prompt: Dict = None,
    conclusion_statement: Dict = None,
    dialog_code_hook: Dict = None,
    fulfillment_activity: Dict = None,
    parent_intent_signature: str = None,
    checksum: str = None,
    create_version: bool = None,
    kendra_configuration: Dict = None,
    input_contexts: List = None,
    output_contexts: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an intent or replaces an existing intent. To define the interaction between the user and your bot, you use one or more intents. For a pizza ordering bot, for example, you would create an OrderPizza intent.  To create an intent or replace an existing intent, you must provide the following:   Intent name. For example, OrderPizza.   Sample utterances. For example, "Can I order a pizza, please." and "I want to order a pizza."   Information to be gathered. You specify slot types for the information that your bot will request from the user. You can specify standard slot types, such as a date or a time, or custom slot types such as the size and crust of a pizza.   How the intent will be fulfilled. You can provide a Lambda function or configure the intent to return the intent information to the client application. If you use a Lambda function, when all of the intent information is available, Amazon Lex invokes your Lambda function. If you configure your intent to return the intent information to the client application.    You can specify other optional information in the request, such as:   A confirmation prompt to ask the user to confirm an intent. For example, "Shall I order your pizza?"   A conclusion statement to send to the user after the intent has been fulfilled. For example, "I placed your pizza order."   A follow-up prompt that asks the user for additional activity. For example, asking "Do you want to order a drink with your pizza?"   If you specify an existing intent name to update the intent, Amazon Lex replaces the values in the $LATEST version of the intent with the values in the request. Amazon Lex removes fields that you don't provide in the request. If you don't specify the required fields, Amazon Lex throws an exception. When you update the $LATEST version of an intent, the status field of any bot that uses the $LATEST version of the intent is set to NOT_BUILT. For more information, see how-it-works. This operation requires permissions for the lex:PutIntent action.

    Args:
        name(str): The name of the intent. The name is not case sensitive.  The name can't match a built-in intent name, or a built-in intent name with "AMAZON." removed. For example, because there is a built-in intent called AMAZON.HelpIntent, you can't create a custom intent called HelpIntent. For a list of built-in intents, see Standard Built-in Intents in the Alexa Skills Kit.
        description(str, optional): A description of the intent. Defaults to None.
        slots(List, optional): An array of intent slots. At runtime, Amazon Lex elicits required slot values from the user using prompts defined in the slots. For more information, see how-it-works. . Defaults to None.
        sample_utterances(List, optional): An array of utterances (strings) that a user might say to signal the intent. For example, "I want {PizzaSize} pizza", "Order {Quantity} {PizzaSize} pizzas".  In each utterance, a slot name is enclosed in curly braces. . Defaults to None.
        confirmation_prompt(Dict, optional): Prompts the user to confirm the intent. This question should have a yes or no answer. Amazon Lex uses this prompt to ensure that the user acknowledges that the intent is ready for fulfillment. For example, with the OrderPizza intent, you might want to confirm that the order is correct before placing it. For other intents, such as intents that simply respond to user questions, you might not need to ask the user for confirmation before providing the information.   You you must provide both the rejectionStatement and the confirmationPrompt, or neither. . Defaults to None.
        rejection_statement(Dict, optional): When the user answers "no" to the question defined in confirmationPrompt, Amazon Lex responds with this statement to acknowledge that the intent was canceled.   You must provide both the rejectionStatement and the confirmationPrompt, or neither. . Defaults to None.
        follow_up_prompt(Dict, optional): Amazon Lex uses this prompt to solicit additional activity after fulfilling an intent. For example, after the OrderPizza intent is fulfilled, you might prompt the user to order a drink. The action that Amazon Lex takes depends on the user's response, as follows:   If the user says "Yes" it responds with the clarification prompt that is configured for the bot.   if the user says "Yes" and continues with an utterance that triggers an intent it starts a conversation for the intent.   If the user says "No" it responds with the rejection statement configured for the the follow-up prompt.   If it doesn't recognize the utterance it repeats the follow-up prompt again.   The followUpPrompt field and the conclusionStatement field are mutually exclusive. You can specify only one. . Defaults to None.
        conclusion_statement(Dict, optional):  The statement that you want Amazon Lex to convey to the user after the intent is successfully fulfilled by the Lambda function.  This element is relevant only if you provide a Lambda function in the fulfillmentActivity. If you return the intent to the client application, you can't specify this element.  The followUpPrompt and conclusionStatement are mutually exclusive. You can specify only one. . Defaults to None.
        dialog_code_hook(Dict, optional):  Specifies a Lambda function to invoke for each user input. You can invoke this Lambda function to personalize user interaction.  For example, suppose your bot determines that the user is John. Your Lambda function might retrieve John's information from a backend database and prepopulate some of the values. For example, if you find that John is gluten intolerant, you might set the corresponding intent slot, GlutenIntolerant, to true. You might find John's phone number and set the corresponding session attribute. . Defaults to None.
        fulfillment_activity(Dict, optional): Required. Describes how the intent is fulfilled. For example, after a user provides all of the information for a pizza order, fulfillmentActivity defines how the bot places an order with a local pizza store.   You might configure Amazon Lex to return all of the intent information to the client application, or direct it to invoke a Lambda function that can process the intent (for example, place an order with a pizzeria). . Defaults to None.
        parent_intent_signature(str, optional): A unique identifier for the built-in intent to base this intent on. To find the signature for an intent, see Standard Built-in Intents in the Alexa Skills Kit. Defaults to None.
        checksum(str, optional): Identifies a specific revision of the $LATEST version. When you create a new intent, leave the checksum field blank. If you specify a checksum you get a BadRequestException exception. When you want to update a intent, set the checksum field to the checksum of the most recent revision of the $LATEST version. If you don't specify the  checksum field, or if the checksum does not match the $LATEST version, you get a PreconditionFailedException exception. Defaults to None.
        create_version(bool, optional): When set to true a new numbered version of the intent is created. This is the same as calling the CreateIntentVersion operation. If you do not specify createVersion, the default is false. Defaults to None.
        kendra_configuration(Dict, optional): Configuration information required to use the AMAZON.KendraSearchIntent intent to connect to an Amazon Kendra index. For more information, see  AMAZON.KendraSearchIntent. Defaults to None.
        input_contexts(List, optional): An array of InputContext objects that lists the contexts that must be active for Amazon Lex to choose the intent in a conversation with the user. Defaults to None.
        output_contexts(List, optional): An array of OutputContext objects that lists the contexts that the intent activates when the intent is fulfilled. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lex_model.intent.init.put(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lex_model.intent.init.put name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lex-models",
        operation="put_intent",
        op_kwargs={
            "name": name,
            "description": description,
            "slots": slots,
            "sampleUtterances": sample_utterances,
            "confirmationPrompt": confirmation_prompt,
            "rejectionStatement": rejection_statement,
            "followUpPrompt": follow_up_prompt,
            "conclusionStatement": conclusion_statement,
            "dialogCodeHook": dialog_code_hook,
            "fulfillmentActivity": fulfillment_activity,
            "parentIntentSignature": parent_intent_signature,
            "checksum": checksum,
            "createVersion": create_version,
            "kendraConfiguration": kendra_configuration,
            "inputContexts": input_contexts,
            "outputContexts": output_contexts,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(
    hub,
    ctx,
    principal: str = None,
    cognito_identity_pool_id: str = None,
    thing_name: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets a list of the policies that have an effect on the authorization behavior of the specified device when it connects to the AWS IoT device gateway.

    Args:
        principal(str, optional): The principal. Valid principals are CertificateArn (arn:aws:iot:region:accountId:cert/certificateId), thingGroupArn (arn:aws:iot:region:accountId:thinggroup/groupName) and CognitoId (region:id). Defaults to None.
        cognito_identity_pool_id(str, optional): The Cognito identity pool ID. Defaults to None.
        thing_name(str, optional): The thing name. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.effective_policy.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.effective_policy.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="get_effective_policies",
        op_kwargs={
            "principal": principal,
            "cognitoIdentityPoolId": cognito_identity_pool_id,
            "thingName": thing_name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx, policy_type: str, target_id: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns the contents of the effective policy for specified policy type and account. The effective policy is the aggregation of any policies of the specified type that the account inherits, plus any policy of that type that is directly attached to the account. This operation applies only to policy types other than service control policies (SCPs). For more information about policy inheritance, see How Policy Inheritance Works in the AWS Organizations User Guide. This operation can be called only from the organization's management account or by a member account that is a delegated administrator for an AWS service.

    Args:
        policy_type(str): The type of policy that you want information about. You can specify one of the following values:    AISERVICES_OPT_OUT_POLICY     BACKUP_POLICY     TAG_POLICY   .
        target_id(str, optional): When you're signed in as the management account, specify the ID of the account that you want details about. Specifying an organization root or organizational unit (OU) as the target is not supported. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.organization.effective_policy.describe(ctx, policy_type=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.organization.effective_policy.describe policy_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="organizations",
        operation="describe_effective_policy",
        op_kwargs={"PolicyType": policy_type, "TargetId": target_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

     This is AWS WAF Classic documentation. For more information, see AWS WAF Classic in the developer guide.  For the latest version of AWS WAF, use the AWS WAFV2 API and see the AWS WAF Developer Guide. With the latest version, AWS WAF has a single set of endpoints for regional and global use.   When you want to create, update, or delete AWS WAF objects, get a change token and include the change token in the create, update, or delete request. Change tokens ensure that your application doesn't submit conflicting requests to AWS WAF. Each create, update, or delete request must use a unique change token. If your application submits a GetChangeToken request and then submits a second GetChangeToken request before submitting a create, update, or delete request, the second GetChangeToken request returns the same value as the first GetChangeToken request. When you use a change token in a create, update, or delete request, the status of the change token changes to PENDING, which indicates that AWS WAF is propagating the change to all AWS WAF servers. Use GetChangeTokenStatus to determine the status of your change token.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.waf.change_token.init.get(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.waf.change_token.init.get
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="waf", operation="get_change_token", op_kwargs={}
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns a MemberAccounts object that lists the member accounts in the administrator's Amazon Web Services organization. The ListMemberAccounts must be submitted by the account that is set as the Firewall Manager administrator.

    Args:
        next_token(str, optional): If you specify a value for MaxResults and you have more account IDs than the number that you specify for MaxResults, Firewall Manager returns a NextToken value in the response that allows you to list another group of IDs. For the second and subsequent ListMemberAccountsRequest requests, specify the value of NextToken from the previous response to get information about another batch of member account IDs. Defaults to None.
        max_results(int, optional): Specifies the number of member account IDs that you want Firewall Manager to return for this request. If you have more IDs than the number that you specify for MaxResults, the response includes a NextToken value that you can use to get another batch of member account IDs. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.fms.member_account.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.fms.member_account.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="fms",
        operation="list_member_accounts",
        op_kwargs={"NextToken": next_token, "MaxResults": max_results},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(
    hub,
    ctx,
    automation_execution_id: str,
    filters: List = None,
    next_token: str = None,
    max_results: int = None,
    reverse_order: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Information about all active and terminated step executions in an Automation workflow.

    Args:
        automation_execution_id(str): The Automation execution ID for which you want step execution descriptions.
        filters(List, optional): One or more filters to limit the number of step executions returned by the request. Defaults to None.
        next_token(str, optional): The token for the next set of items to return. (You received this token from a previous call.). Defaults to None.
        max_results(int, optional): The maximum number of items to return for this call. The call also returns a token that you can specify in a subsequent call to get the next set of results. Defaults to None.
        reverse_order(bool, optional): Indicates whether to list step executions in reverse order by start time. The default value is 'false'. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.automation.step_execution.describe_all(
                ctx, automation_execution_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.automation.step_execution.describe_all automation_execution_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="describe_automation_step_executions",
        op_kwargs={
            "AutomationExecutionId": automation_execution_id,
            "Filters": filters,
            "NextToken": next_token,
            "MaxResults": max_results,
            "ReverseOrder": reverse_order,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(
    hub, ctx, resource_arn: str, next_marker: str = None, limit: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the TagInfoForResource for the specified resource. Tags are key:value pairs that you can use to categorize and manage your resources, for purposes like billing. For example, you might set the tag key to "customer" and the value to the customer name or ID. You can specify one or more tags to add to each Amazon Web Services resource, up to 50 tags for a resource. You can tag the Amazon Web Services resources that you manage through WAF: web ACLs, rule groups, IP sets, and regex pattern sets. You can't manage or view tags through the WAF console.

    Args:
        next_marker(str, optional): When you request a list of objects with a Limit setting, if the number of objects that are still available for retrieval exceeds the limit, WAF returns a NextMarker value in the response. To retrieve the next batch of objects, provide the marker from the prior call in your next request. Defaults to None.
        limit(int, optional): The maximum number of objects that you want WAF to return for this request. If more objects are available, in the response, WAF provides a NextMarker value that you can use in a subsequent call to get the next batch of objects. Defaults to None.
        resource_arn(str): The Amazon Resource Name (ARN) of the resource.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.wafv2.tags_for_resource.list(ctx, resource_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.wafv2.tags_for_resource.list resource_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="wafv2",
        operation="list_tags_for_resource",
        op_kwargs={
            "NextMarker": next_marker,
            "Limit": limit,
            "ResourceARN": resource_arn,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(
    hub,
    ctx,
    reserved_db_instance_id: str = None,
    reserved_db_instances_offering_id: str = None,
    db_instance_class: str = None,
    duration: str = None,
    product_description: str = None,
    offering_type: str = None,
    multi_az: bool = None,
    lease_id: str = None,
    filters: List = None,
    max_records: int = None,
    marker: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about reserved DB instances for this account, or about a specified reserved DB instance.

    Args:
        reserved_db_instance_id(str, optional): The reserved DB instance identifier filter value. Specify this parameter to show only the reservation that matches the specified reservation ID. Defaults to None.
        reserved_db_instances_offering_id(str, optional): The offering identifier filter value. Specify this parameter to show only purchased reservations matching the specified offering identifier. Defaults to None.
        db_instance_class(str, optional): The DB instance class filter value. Specify this parameter to show only those reservations matching the specified DB instances class. Defaults to None.
        duration(str, optional): The duration filter value, specified in years or seconds. Specify this parameter to show only reservations for this duration. Valid Values: 1 | 3 | 31536000 | 94608000 . Defaults to None.
        product_description(str, optional): The product description filter value. Specify this parameter to show only those reservations matching the specified product description. Defaults to None.
        offering_type(str, optional): The offering type filter value. Specify this parameter to show only the available offerings matching the specified offering type. Valid Values: "Partial Upfront" | "All Upfront" | "No Upfront"  . Defaults to None.
        multi_az(bool, optional): A value that indicates whether to show only those reservations that support Multi-AZ. Defaults to None.
        lease_id(str, optional): The lease identifier filter value. Specify this parameter to show only the reservation that matches the specified lease ID.  Amazon Web Services Support might request the lease ID for an issue related to a reserved DB instance. . Defaults to None.
        filters(List, optional): This parameter isn't currently supported. Defaults to None.
        max_records(int, optional):  The maximum number of records to include in the response. If more than the MaxRecords value is available, a pagination token called a marker is included in the response so you can retrieve the remaining results.  Default: 100 Constraints: Minimum 20, maximum 100. Defaults to None.
        marker(str, optional):  An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.reserved_db_instance.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.reserved_db_instance.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds",
        operation="describe_reserved_db_instances",
        op_kwargs={
            "ReservedDBInstanceId": reserved_db_instance_id,
            "ReservedDBInstancesOfferingId": reserved_db_instances_offering_id,
            "DBInstanceClass": db_instance_class,
            "Duration": duration,
            "ProductDescription": product_description,
            "OfferingType": offering_type,
            "MultiAZ": multi_az,
            "LeaseId": lease_id,
            "Filters": filters,
            "MaxRecords": max_records,
            "Marker": marker,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def copy(
    hub,
    ctx,
    source_option_group_identifier: str,
    target_option_group_identifier: str,
    target_option_group_description: str,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Copies the specified option group.

    Args:
        source_option_group_identifier(str): The identifier for the source option group.  Constraints:   Must specify a valid option group.  .
        target_option_group_identifier(str): The identifier for the copied option group. Constraints:   Can't be null, empty, or blank   Must contain from 1 to 255 letters, numbers, or hyphens   First character must be a letter   Can't end with a hyphen or contain two consecutive hyphens   Example: my-option-group .
        target_option_group_description(str): The description for the copied option group.
        tags(List, optional): A list of tags. For more information, see Tagging Amazon RDS Resources in the Amazon RDS User Guide. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.option_group.init.copy(
                ctx,
                source_option_group_identifier=value,
                target_option_group_identifier=value,
                target_option_group_description=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.option_group.init.copy source_option_group_identifier=value, target_option_group_identifier=value, target_option_group_description=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds",
        operation="copy_option_group",
        op_kwargs={
            "SourceOptionGroupIdentifier": source_option_group_identifier,
            "TargetOptionGroupIdentifier": target_option_group_identifier,
            "TargetOptionGroupDescription": target_option_group_description,
            "Tags": tags,
        },
    )


async def create(
    hub,
    ctx,
    option_group_name: str,
    engine_name: str,
    major_engine_version: str,
    option_group_description: str,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new option group. You can create up to 20 option groups.

    Args:
        option_group_name(str): Specifies the name of the option group to be created. Constraints:   Must be 1 to 255 letters, numbers, or hyphens   First character must be a letter   Can't end with a hyphen or contain two consecutive hyphens   Example: myoptiongroup .
        engine_name(str): Specifies the name of the engine that this option group should be associated with. Valid Values:     mariadb     mysql     oracle-ee     oracle-ee-cdb     oracle-se2     oracle-se2-cdb     postgres     sqlserver-ee     sqlserver-se     sqlserver-ex     sqlserver-web   .
        major_engine_version(str): Specifies the major version of the engine that this option group should be associated with.
        option_group_description(str): The description of the option group.
        tags(List, optional): Tags to assign to the option group. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.option_group.init.create(
                ctx,
                option_group_name=value,
                engine_name=value,
                major_engine_version=value,
                option_group_description=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.option_group.init.create option_group_name=value, engine_name=value, major_engine_version=value, option_group_description=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds",
        operation="create_option_group",
        op_kwargs={
            "OptionGroupName": option_group_name,
            "EngineName": engine_name,
            "MajorEngineVersion": major_engine_version,
            "OptionGroupDescription": option_group_description,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, option_group_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes an existing option group.

    Args:
        option_group_name(str): The name of the option group to be deleted.  You can't delete default option groups. .
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.option_group.init.delete(ctx, option_group_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.option_group.init.delete option_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds",
        operation="delete_option_group",
        op_kwargs={"OptionGroupName": option_group_name},
    )


async def describe_all(
    hub,
    ctx,
    option_group_name: str = None,
    filters: List = None,
    marker: str = None,
    max_records: int = None,
    engine_name: str = None,
    major_engine_version: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the available option groups.

    Args:
        option_group_name(str, optional): The name of the option group to describe. Can't be supplied together with EngineName or MajorEngineVersion. Defaults to None.
        filters(List, optional): This parameter isn't currently supported. Defaults to None.
        marker(str, optional):  An optional pagination token provided by a previous DescribeOptionGroups request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords. . Defaults to None.
        max_records(int, optional):  The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that you can retrieve the remaining results.  Default: 100 Constraints: Minimum 20, maximum 100. Defaults to None.
        engine_name(str, optional): Filters the list of option groups to only include groups associated with a specific database engine. Valid Values:     mariadb     mysql     oracle-ee     oracle-ee-cdb     oracle-se2     oracle-se2-cdb     postgres     sqlserver-ee     sqlserver-se     sqlserver-ex     sqlserver-web   . Defaults to None.
        major_engine_version(str, optional): Filters the list of option groups to only include groups associated with a specific database engine version. If specified, then EngineName must also be specified. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.option_group.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.option_group.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds",
        operation="describe_option_groups",
        op_kwargs={
            "OptionGroupName": option_group_name,
            "Filters": filters,
            "Marker": marker,
            "MaxRecords": max_records,
            "EngineName": engine_name,
            "MajorEngineVersion": major_engine_version,
        },
    )


async def modify(
    hub,
    ctx,
    option_group_name: str,
    options_to_include: List = None,
    options_to_remove: List = None,
    apply_immediately: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Modifies an existing option group.

    Args:
        option_group_name(str): The name of the option group to be modified. Permanent options, such as the TDE option for Oracle Advanced Security TDE, can't be removed from an option group, and that option group can't be removed from a DB instance once it is associated with a DB instance.
        options_to_include(List, optional): Options in this list are added to the option group or, if already present, the specified configuration is used to update the existing configuration. Defaults to None.
        options_to_remove(List, optional): Options in this list are removed from the option group. Defaults to None.
        apply_immediately(bool, optional): A value that indicates whether to apply the change immediately or during the next maintenance window for each instance associated with the option group. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.option_group.init.modify(ctx, option_group_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.option_group.init.modify option_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds",
        operation="modify_option_group",
        op_kwargs={
            "OptionGroupName": option_group_name,
            "OptionsToInclude": options_to_include,
            "OptionsToRemove": options_to_remove,
            "ApplyImmediately": apply_immediately,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx, instance_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes the hierarchy structure of the specified Amazon Connect instance.

    Args:
        instance_id(str): The identifier of the Amazon Connect instance. You can find the instanceId in the ARN of the instance.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.connect.user.hierarchy.structure.describe(
                ctx, instance_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.connect.user.hierarchy.structure.describe instance_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="connect",
        operation="describe_user_hierarchy_structure",
        op_kwargs={"InstanceId": instance_id},
    )


async def update(hub, ctx, hierarchy_structure: Dict, instance_id: str) -> None:
    r"""
    **Autogenerated function**

    Updates the user hierarchy structure: add, remove, and rename user hierarchy levels.

    Args:
        hierarchy_structure(Dict): The hierarchy levels to update.
        instance_id(str): The identifier of the Amazon Connect instance. You can find the instanceId in the ARN of the instance.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.connect.user.hierarchy.structure.update(
                ctx, hierarchy_structure=value, instance_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.connect.user.hierarchy.structure.update hierarchy_structure=value, instance_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="connect",
        operation="update_user_hierarchy_structure",
        op_kwargs={
            "HierarchyStructure": hierarchy_structure,
            "InstanceId": instance_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub,
    ctx,
    template_body: str = None,
    template_url: str = None,
    stack_name: str = None,
    stack_set_name: str = None,
    call_as: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about a new or existing template. The GetTemplateSummary action is useful for viewing parameter information, such as default parameter values and parameter types, before you create or update a stack or stack set. You can use the GetTemplateSummary action when you submit a template, or you can get template information for a stack set, or a running or deleted stack. For deleted stacks, GetTemplateSummary returns the template information for up to 90 days after the stack has been deleted. If the template does not exist, a ValidationError is returned.

    Args:
        template_body(str, optional): Structure containing the template body with a minimum length of 1 byte and a maximum length of 51,200 bytes. For more information about templates, see Template Anatomy in the CloudFormation User Guide. Conditional: You must specify only one of the following parameters: StackName, StackSetName, TemplateBody, or TemplateURL. Defaults to None.
        template_url(str, optional): Location of file containing the template body. The URL must point to a template (max size: 460,800 bytes) that is located in an Amazon S3 bucket or a Systems Manager document. For more information about templates, see Template Anatomy in the CloudFormation User Guide. Conditional: You must specify only one of the following parameters: StackName, StackSetName, TemplateBody, or TemplateURL. Defaults to None.
        stack_name(str, optional): The name or the stack ID that is associated with the stack, which are not always interchangeable. For running stacks, you can specify either the stack's name or its unique stack ID. For deleted stack, you must specify the unique stack ID. Conditional: You must specify only one of the following parameters: StackName, StackSetName, TemplateBody, or TemplateURL. Defaults to None.
        stack_set_name(str, optional): The name or unique ID of the stack set from which the stack was created. Conditional: You must specify only one of the following parameters: StackName, StackSetName, TemplateBody, or TemplateURL. Defaults to None.
        call_as(str, optional): [Service-managed permissions] Specifies whether you are acting as an account administrator in the organization's management account or as a delegated administrator in a member account. By default, SELF is specified. Use SELF for stack sets with self-managed permissions.   If you are signed in to the management account, specify SELF.   If you are signed in to a delegated administrator account, specify DELEGATED_ADMIN. Your account must be registered as a delegated administrator in the management account. For more information, see Register a delegated administrator in the CloudFormation User Guide.  . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudformation.template.summary.get(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudformation.template.summary.get
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudformation",
        operation="get_template_summary",
        op_kwargs={
            "TemplateBody": template_body,
            "TemplateURL": template_url,
            "StackName": stack_name,
            "StackSetName": stack_set_name,
            "CallAs": call_as,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def install(hub, ctx, remote_access_session_arn: str, app_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Installs an application to the device in a remote access session. For Android applications, the file must be in .apk format. For iOS applications, the file must be in .ipa format.

    Args:
        remote_access_session_arn(str): The Amazon Resource Name (ARN) of the remote access session about which you are requesting information.
        app_arn(str): The ARN of the app about which you are requesting information.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devicefarm.to_remote_access_session.install(
                ctx, remote_access_session_arn=value, app_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devicefarm.to_remote_access_session.install remote_access_session_arn=value, app_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="devicefarm",
        operation="install_to_remote_access_session",
        op_kwargs={
            "remoteAccessSessionArn": remote_access_session_arn,
            "appArn": app_arn,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def put(
    hub, ctx, cluster_id: str, instance_group_id: str, auto_scaling_policy: Dict
) -> Dict:
    r"""
    **Autogenerated function**

    Creates or updates an automatic scaling policy for a core instance group or task instance group in an Amazon EMR cluster. The automatic scaling policy defines how an instance group dynamically adds and terminates EC2 instances in response to the value of a CloudWatch metric.

    Args:
        cluster_id(str): Specifies the ID of a cluster. The instance group to which the automatic scaling policy is applied is within this cluster.
        instance_group_id(str): Specifies the ID of the instance group to which the automatic scaling policy is applied.
        auto_scaling_policy(Dict): Specifies the definition of the automatic scaling policy.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.emr.auto_scaling_policy.put(
                ctx, cluster_id=value, instance_group_id=value, auto_scaling_policy=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.emr.auto_scaling_policy.put cluster_id=value, instance_group_id=value, auto_scaling_policy=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="emr",
        operation="put_auto_scaling_policy",
        op_kwargs={
            "ClusterId": cluster_id,
            "InstanceGroupId": instance_group_id,
            "AutoScalingPolicy": auto_scaling_policy,
        },
    )


async def remove(hub, ctx, cluster_id: str, instance_group_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Removes an automatic scaling policy from a specified instance group within an EMR cluster.

    Args:
        cluster_id(str): Specifies the ID of a cluster. The instance group to which the automatic scaling policy is applied is within this cluster.
        instance_group_id(str): Specifies the ID of the instance group to which the scaling policy is applied.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.emr.auto_scaling_policy.remove(
                ctx, cluster_id=value, instance_group_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.emr.auto_scaling_policy.remove cluster_id=value, instance_group_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="emr",
        operation="remove_auto_scaling_policy",
        op_kwargs={"ClusterId": cluster_id, "InstanceGroupId": instance_group_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    document_classifier_name: str,
    data_access_role_arn: str,
    input_data_config: Dict,
    language_code: str,
    tags: List = None,
    output_data_config: Dict = None,
    client_request_token: str = None,
    volume_kms_key_id: str = None,
    vpc_config: Dict = None,
    mode: str = None,
    model_kms_key_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new document classifier that you can use to categorize documents. To create a classifier, you provide a set of training documents that labeled with the categories that you want to use. After the classifier is trained you can use it to categorize a set of labeled documents into the categories. For more information, see how-document-classification.

    Args:
        document_classifier_name(str): The name of the document classifier.
        data_access_role_arn(str): The Amazon Resource Name (ARN) of the AWS Identity and Management (IAM) role that grants Amazon Comprehend read access to your input data.
        tags(List, optional): Tags to be associated with the document classifier being created. A tag is a key-value pair that adds as a metadata to a resource used by Amazon Comprehend. For example, a tag with "Sales" as the key might be added to a resource to indicate its use by the sales department. . Defaults to None.
        input_data_config(Dict): Specifies the format and location of the input data for the job.
        output_data_config(Dict, optional): Enables the addition of output results configuration parameters for custom classifier jobs. Defaults to None.
        client_request_token(str, optional): A unique identifier for the request. If you don't set the client request token, Amazon Comprehend generates one. Defaults to None.
        language_code(str): The language of the input documents. You can specify any of the following languages supported by Amazon Comprehend: German ("de"), English ("en"), Spanish ("es"), French ("fr"), Italian ("it"), or Portuguese ("pt"). All documents must be in the same language.
        volume_kms_key_id(str, optional): ID for the AWS Key Management Service (KMS) key that Amazon Comprehend uses to encrypt data on the storage volume attached to the ML compute instance(s) that process the analysis job. The VolumeKmsKeyId can be either of the following formats:   KMS Key ID: "1234abcd-12ab-34cd-56ef-1234567890ab"    Amazon Resource Name (ARN) of a KMS Key: "arn:aws:kms:us-west-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab"   . Defaults to None.
        vpc_config(Dict, optional): Configuration parameters for an optional private Virtual Private Cloud (VPC) containing the resources you are using for your custom classifier. For more information, see Amazon VPC. . Defaults to None.
        mode(str, optional): Indicates the mode in which the classifier will be trained. The classifier can be trained in multi-class mode, which identifies one and only one class for each document, or multi-label mode, which identifies one or more labels for each document. In multi-label mode, multiple labels for an individual document are separated by a delimiter. The default delimiter between labels is a pipe (|). Defaults to None.
        model_kms_key_id(str, optional): ID for the AWS Key Management Service (KMS) key that Amazon Comprehend uses to encrypt trained custom models. The ModelKmsKeyId can be either of the following formats:   KMS Key ID: "1234abcd-12ab-34cd-56ef-1234567890ab"    Amazon Resource Name (ARN) of a KMS Key: "arn:aws:kms:us-west-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab"   . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.comprehend.document.classifier.create(
                ctx,
                document_classifier_name=value,
                data_access_role_arn=value,
                input_data_config=value,
                language_code=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.comprehend.document.classifier.create document_classifier_name=value, data_access_role_arn=value, input_data_config=value, language_code=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="comprehend",
        operation="create_document_classifier",
        op_kwargs={
            "DocumentClassifierName": document_classifier_name,
            "DataAccessRoleArn": data_access_role_arn,
            "Tags": tags,
            "InputDataConfig": input_data_config,
            "OutputDataConfig": output_data_config,
            "ClientRequestToken": client_request_token,
            "LanguageCode": language_code,
            "VolumeKmsKeyId": volume_kms_key_id,
            "VpcConfig": vpc_config,
            "Mode": mode,
            "ModelKmsKeyId": model_kms_key_id,
        },
    )


async def delete(hub, ctx, document_classifier_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a previously created document classifier Only those classifiers that are in terminated states (IN_ERROR, TRAINED) will be deleted. If an active inference job is using the model, a ResourceInUseException will be returned. This is an asynchronous action that puts the classifier into a DELETING state, and it is then removed by a background job. Once removed, the classifier disappears from your account and is no longer available for use.

    Args:
        document_classifier_arn(str): The Amazon Resource Name (ARN) that identifies the document classifier. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.comprehend.document.classifier.delete(
                ctx, document_classifier_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.comprehend.document.classifier.delete document_classifier_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="comprehend",
        operation="delete_document_classifier",
        op_kwargs={"DocumentClassifierArn": document_classifier_arn},
    )


async def describe(hub, ctx, document_classifier_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets the properties associated with a document classifier.

    Args:
        document_classifier_arn(str): The Amazon Resource Name (ARN) that identifies the document classifier. The operation returns this identifier in its response.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.comprehend.document.classifier.describe(
                ctx, document_classifier_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.comprehend.document.classifier.describe document_classifier_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="comprehend",
        operation="describe_document_classifier",
        op_kwargs={"DocumentClassifierArn": document_classifier_arn},
    )


async def list_all(
    hub, ctx, filter_: Dict = None, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Gets a list of the document classifiers that you have created.

    Args:
        filter_(Dict, optional): Filters the jobs that are returned. You can filter jobs on their name, status, or the date and time that they were submitted. You can only set one filter at a time. Defaults to None.
        next_token(str, optional): Identifies the next page of results to return. Defaults to None.
        max_results(int, optional): The maximum number of results to return in each page. The default is 100. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.comprehend.document.classifier.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.comprehend.document.classifier.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="comprehend",
        operation="list_document_classifiers",
        op_kwargs={
            "Filter": filter_,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx, vendor_name: str, name: str, scope: str) -> Dict:
    r"""
    **Autogenerated function**

    Provides high-level information for a managed rule group, including descriptions of the rules.

    Args:
        vendor_name(str): The name of the managed rule group vendor. You use this, along with the rule group name, to identify the rule group.
        name(str): The name of the managed rule group. You use this, along with the vendor name, to identify the rule group.
        scope(str): Specifies whether this is for an Amazon CloudFront distribution or for a regional application. A regional application can be an Application Load Balancer (ALB), an Amazon API Gateway REST API, or an AppSync GraphQL API.  To work with CloudFront, you must also specify the Region US East (N. Virginia) as follows:    CLI - Specify the Region when you use the CloudFront scope: --scope=CLOUDFRONT --region=us-east-1.    API and SDKs - For all calls, use the Region endpoint us-east-1.   .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.wafv2.managed_rule_group.describe(
                ctx, vendor_name=value, name=value, scope=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.wafv2.managed_rule_group.describe vendor_name=value, name=value, scope=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="wafv2",
        operation="describe_managed_rule_group",
        op_kwargs={"VendorName": vendor_name, "Name": name, "Scope": scope},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    db_proxy_name: str,
    engine_family: str,
    auth: List,
    role_arn: str,
    vpc_subnet_ids: List,
    vpc_security_group_ids: List = None,
    require_tls: bool = None,
    idle_client_timeout: int = None,
    debug_logging: bool = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new DB proxy.

    Args:
        db_proxy_name(str): The identifier for the proxy. This name must be unique for all proxies owned by your Amazon Web Services account in the specified Amazon Web Services Region. An identifier must begin with a letter and must contain only ASCII letters, digits, and hyphens; it can't end with a hyphen or contain two consecutive hyphens.
        engine_family(str): The kinds of databases that the proxy can connect to. This value determines which database network protocol the proxy recognizes when it interprets network traffic to and from the database. The engine family applies to MySQL and PostgreSQL for both RDS and Aurora.
        auth(List): The authorization mechanism that the proxy uses.
        role_arn(str): The Amazon Resource Name (ARN) of the IAM role that the proxy uses to access secrets in Amazon Web Services Secrets Manager.
        vpc_subnet_ids(List): One or more VPC subnet IDs to associate with the new proxy.
        vpc_security_group_ids(List, optional): One or more VPC security group IDs to associate with the new proxy. Defaults to None.
        require_tls(bool, optional): A Boolean parameter that specifies whether Transport Layer Security (TLS) encryption is required for connections to the proxy. By enabling this setting, you can enforce encrypted TLS connections to the proxy. Defaults to None.
        idle_client_timeout(int, optional): The number of seconds that a connection to the proxy can be inactive before the proxy disconnects it. You can set this value higher or lower than the connection timeout limit for the associated database. Defaults to None.
        debug_logging(bool, optional): Whether the proxy includes detailed information about SQL statements in its logs. This information helps you to debug issues involving SQL behavior or the performance and scalability of the proxy connections. The debug information includes the text of SQL statements that you submit through the proxy. Thus, only enable this setting when needed for debugging, and only when you have security measures in place to safeguard any sensitive information that appears in the logs. Defaults to None.
        tags(List, optional): An optional set of key-value pairs to associate arbitrary data of your choosing with the proxy. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.db.proxy.init.create(
                ctx,
                db_proxy_name=value,
                engine_family=value,
                auth=value,
                role_arn=value,
                vpc_subnet_ids=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.db.proxy.init.create db_proxy_name=value, engine_family=value, auth=value, role_arn=value, vpc_subnet_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds",
        operation="create_db_proxy",
        op_kwargs={
            "DBProxyName": db_proxy_name,
            "EngineFamily": engine_family,
            "Auth": auth,
            "RoleArn": role_arn,
            "VpcSubnetIds": vpc_subnet_ids,
            "VpcSecurityGroupIds": vpc_security_group_ids,
            "RequireTLS": require_tls,
            "IdleClientTimeout": idle_client_timeout,
            "DebugLogging": debug_logging,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, db_proxy_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an existing DB proxy.

    Args:
        db_proxy_name(str): The name of the DB proxy to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.db.proxy.init.delete(ctx, db_proxy_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.db.proxy.init.delete db_proxy_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds",
        operation="delete_db_proxy",
        op_kwargs={"DBProxyName": db_proxy_name},
    )


async def describe_all(
    hub,
    ctx,
    db_proxy_name: str = None,
    filters: List = None,
    marker: str = None,
    max_records: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about DB proxies.

    Args:
        db_proxy_name(str, optional): The name of the DB proxy. If you omit this parameter, the output includes information about all DB proxies owned by your Amazon Web Services account ID. Defaults to None.
        filters(List, optional): This parameter is not currently supported. Defaults to None.
        marker(str, optional):  An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords. . Defaults to None.
        max_records(int, optional): The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that the remaining results can be retrieved.  Default: 100 Constraints: Minimum 20, maximum 100. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.db.proxy.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.db.proxy.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds",
        operation="describe_db_proxies",
        op_kwargs={
            "DBProxyName": db_proxy_name,
            "Filters": filters,
            "Marker": marker,
            "MaxRecords": max_records,
        },
    )


async def modify(
    hub,
    ctx,
    db_proxy_name: str,
    new_db_proxy_name: str = None,
    auth: List = None,
    require_tls: bool = None,
    idle_client_timeout: int = None,
    debug_logging: bool = None,
    role_arn: str = None,
    security_groups: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Changes the settings for an existing DB proxy.

    Args:
        db_proxy_name(str): The identifier for the DBProxy to modify.
        new_db_proxy_name(str, optional): The new identifier for the DBProxy. An identifier must begin with a letter and must contain only ASCII letters, digits, and hyphens; it can't end with a hyphen or contain two consecutive hyphens. Defaults to None.
        auth(List, optional): The new authentication settings for the DBProxy. Defaults to None.
        require_tls(bool, optional): Whether Transport Layer Security (TLS) encryption is required for connections to the proxy. By enabling this setting, you can enforce encrypted TLS connections to the proxy, even if the associated database doesn't use TLS. Defaults to None.
        idle_client_timeout(int, optional): The number of seconds that a connection to the proxy can be inactive before the proxy disconnects it. You can set this value higher or lower than the connection timeout limit for the associated database. Defaults to None.
        debug_logging(bool, optional): Whether the proxy includes detailed information about SQL statements in its logs. This information helps you to debug issues involving SQL behavior or the performance and scalability of the proxy connections. The debug information includes the text of SQL statements that you submit through the proxy. Thus, only enable this setting when needed for debugging, and only when you have security measures in place to safeguard any sensitive information that appears in the logs. Defaults to None.
        role_arn(str, optional): The Amazon Resource Name (ARN) of the IAM role that the proxy uses to access secrets in Amazon Web Services Secrets Manager. Defaults to None.
        security_groups(List, optional): The new list of security groups for the DBProxy. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.db.proxy.init.modify(ctx, db_proxy_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.db.proxy.init.modify db_proxy_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds",
        operation="modify_db_proxy",
        op_kwargs={
            "DBProxyName": db_proxy_name,
            "NewDBProxyName": new_db_proxy_name,
            "Auth": auth,
            "RequireTLS": require_tls,
            "IdleClientTimeout": idle_client_timeout,
            "DebugLogging": debug_logging,
            "RoleArn": role_arn,
            "SecurityGroups": security_groups,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx, service_name: str, image: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a container image that is registered to your Amazon Lightsail container service.

    Args:
        service_name(str): The name of the container service for which to delete a registered container image.
        image(str): The name of the container image to delete from the container service. Use the GetContainerImages action to get the name of the container images that are registered to a container service.  Container images sourced from your Lightsail container service, that are registered and stored on your service, start with a colon (:). For example, :container-service-1.mystaticwebsite.1. Container images sourced from a public registry like Docker Hub don't start with a colon. For example, nginx:latest or nginx. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.container.image.delete(
                ctx, service_name=value, image=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.container.image.delete service_name=value, image=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="delete_container_image",
        op_kwargs={"serviceName": service_name, "image": image},
    )


async def get_all(hub, ctx, service_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns the container images that are registered to your Amazon Lightsail container service.  If you created a deployment on your Lightsail container service that uses container images from a public registry like Docker Hub, those images are not returned as part of this action. Those images are not registered to your Lightsail container service.

    Args:
        service_name(str): The name of the container service for which to return registered container images.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.container.image.get_all(ctx, service_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.container.image.get_all service_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="get_container_images",
        op_kwargs={"serviceName": service_name},
    )


async def register(hub, ctx, service_name: str, label: str, digest: str) -> Dict:
    r"""
    **Autogenerated function**

    Registers a container image to your Amazon Lightsail container service.  This action is not required if you install and use the Lightsail Control (lightsailctl) plugin to push container images to your Lightsail container service. For more information, see Pushing and managing container images on your Amazon Lightsail container services in the Amazon Lightsail Developer Guide.

    Args:
        service_name(str): The name of the container service for which to register a container image.
        label(str): The label for the container image when it's registered to the container service. Use a descriptive label that you can use to track the different versions of your registered container images. Use the GetContainerImages action to return the container images registered to a Lightsail container service. The label is the <imagelabel> portion of the following image name example:    :container-service-1.<imagelabel>.1    If the name of your container service is mycontainerservice, and the label that you specify is mystaticwebsite, then the name of the registered container image will be :mycontainerservice.mystaticwebsite.1. The number at the end of these image name examples represents the version of the registered container image. If you push and register another container image to the same Lightsail container service, with the same label, then the version number for the new registered container image will be 2. If you push and register another container image, the version number will be 3, and so on.
        digest(str): The digest of the container image to be registered.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.container.image.register(
                ctx, service_name=value, label=value, digest=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.container.image.register service_name=value, label=value, digest=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="register_container_image",
        op_kwargs={"serviceName": service_name, "label": label, "digest": digest},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def delete(hub, ctx, name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes all versions of the bot, including the $LATEST version. To delete a specific version of the bot, use the DeleteBotVersion operation. The DeleteBot operation doesn't immediately remove the bot schema. Instead, it is marked for deletion and removed later. Amazon Lex stores utterances indefinitely for improving the ability of your bot to respond to user inputs. These utterances are not removed when the bot is deleted. To remove the utterances, use the DeleteUtterances operation. If a bot has an alias, you can't delete it. Instead, the DeleteBot operation returns a ResourceInUseException exception that includes a reference to the alias that refers to the bot. To remove the reference to the bot, delete the alias. If you get the same exception again, delete the referring alias until the DeleteBot operation is successful. This operation requires permissions for the lex:DeleteBot action.

    Args:
        name(str): The name of the bot. The name is case sensitive. .
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lex_model.bot.init.delete(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lex_model.bot.init.delete name=value
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="lex-models", operation="delete_bot", op_kwargs={"name": name}
    )


async def get(hub, ctx, name: str, version_or_alias: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns metadata information for a specific bot. You must provide the bot name and the bot version or alias.   This operation requires permissions for the lex:GetBot action.

    Args:
        name(str): The name of the bot. The name is case sensitive. .
        version_or_alias(str): The version or alias of the bot.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lex_model.bot.init.get(ctx, name=value, version_or_alias=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lex_model.bot.init.get name=value, version_or_alias=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lex-models",
        operation="get_bot",
        op_kwargs={"name": name, "versionOrAlias": version_or_alias},
    )


async def put(
    hub,
    ctx,
    name: str,
    locale: str,
    child_directed: bool,
    description: str = None,
    intents: List = None,
    enable_model_improvements: bool = None,
    nlu_intent_confidence_threshold: float = None,
    clarification_prompt: Dict = None,
    abort_statement: Dict = None,
    idle_session_ttl_in_seconds: int = None,
    voice_id: str = None,
    checksum: str = None,
    process_behavior: str = None,
    detect_sentiment: bool = None,
    create_version: bool = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an Amazon Lex conversational bot or replaces an existing bot. When you create or update a bot you are only required to specify a name, a locale, and whether the bot is directed toward children under age 13. You can use this to add intents later, or to remove intents from an existing bot. When you create a bot with the minimum information, the bot is created or updated but Amazon Lex returns the  response FAILED. You can build the bot after you add one or more intents. For more information about Amazon Lex bots, see how-it-works.  If you specify the name of an existing bot, the fields in the request replace the existing values in the $LATEST version of the bot. Amazon Lex removes any fields that you don't provide values for in the request, except for the idleTTLInSeconds and privacySettings fields, which are set to their default values. If you don't specify values for required fields, Amazon Lex throws an exception. This operation requires permissions for the lex:PutBot action. For more information, see security-iam.

    Args:
        name(str): The name of the bot. The name is not case sensitive. .
        description(str, optional): A description of the bot. Defaults to None.
        intents(List, optional): An array of Intent objects. Each intent represents a command that a user can express. For example, a pizza ordering bot might support an OrderPizza intent. For more information, see how-it-works. Defaults to None.
        enable_model_improvements(bool, optional): Set to true to enable access to natural language understanding improvements.  When you set the enableModelImprovements parameter to true you can use the nluIntentConfidenceThreshold parameter to configure confidence scores. For more information, see Confidence Scores. You can only set the enableModelImprovements parameter in certain Regions. If you set the parameter to true, your bot has access to accuracy improvements. The Regions where you can set the enableModelImprovements parameter to true are:   US East (N. Virginia) (us-east-1)   US West (Oregon) (us-west-2)   Asia Pacific (Sydney) (ap-southeast-2)   EU (Ireland) (eu-west-1)   In other Regions, the enableModelImprovements parameter is set to true by default. In these Regions setting the parameter to false throws a ValidationException exception. Defaults to None.
        nlu_intent_confidence_threshold(float, optional): Determines the threshold where Amazon Lex will insert the AMAZON.FallbackIntent, AMAZON.KendraSearchIntent, or both when returning alternative intents in a PostContent or PostText response. AMAZON.FallbackIntent and AMAZON.KendraSearchIntent are only inserted if they are configured for the bot. You must set the enableModelImprovements parameter to true to use confidence scores in the following regions.   US East (N. Virginia) (us-east-1)   US West (Oregon) (us-west-2)   Asia Pacific (Sydney) (ap-southeast-2)   EU (Ireland) (eu-west-1)   In other Regions, the enableModelImprovements parameter is set to true by default. For example, suppose a bot is configured with the confidence threshold of 0.80 and the AMAZON.FallbackIntent. Amazon Lex returns three alternative intents with the following confidence scores: IntentA (0.70), IntentB (0.60), IntentC (0.50). The response from the PostText operation would be:   AMAZON.FallbackIntent   IntentA   IntentB   IntentC  . Defaults to None.
        clarification_prompt(Dict, optional): When Amazon Lex doesn't understand the user's intent, it uses this message to get clarification. To specify how many times Amazon Lex should repeat the clarification prompt, use the maxAttempts field. If Amazon Lex still doesn't understand, it sends the message in the abortStatement field.  When you create a clarification prompt, make sure that it suggests the correct response from the user. for example, for a bot that orders pizza and drinks, you might create this clarification prompt: "What would you like to do? You can say 'Order a pizza' or 'Order a drink.'" If you have defined a fallback intent, it will be invoked if the clarification prompt is repeated the number of times defined in the maxAttempts field. For more information, see  AMAZON.FallbackIntent. If you don't define a clarification prompt, at runtime Amazon Lex will return a 400 Bad Request exception in three cases:    Follow-up prompt - When the user responds to a follow-up prompt but does not provide an intent. For example, in response to a follow-up prompt that says "Would you like anything else today?" the user says "Yes." Amazon Lex will return a 400 Bad Request exception because it does not have a clarification prompt to send to the user to get an intent.   Lambda function - When using a Lambda function, you return an ElicitIntent dialog type. Since Amazon Lex does not have a clarification prompt to get an intent from the user, it returns a 400 Bad Request exception.   PutSession operation - When using the PutSession operation, you send an ElicitIntent dialog type. Since Amazon Lex does not have a clarification prompt to get an intent from the user, it returns a 400 Bad Request exception.  . Defaults to None.
        abort_statement(Dict, optional): When Amazon Lex can't understand the user's input in context, it tries to elicit the information a few times. After that, Amazon Lex sends the message defined in abortStatement to the user, and then cancels the conversation. To set the number of retries, use the valueElicitationPrompt field for the slot type.  For example, in a pizza ordering bot, Amazon Lex might ask a user "What type of crust would you like?" If the user's response is not one of the expected responses (for example, "thin crust, "deep dish," etc.), Amazon Lex tries to elicit a correct response a few more times.  For example, in a pizza ordering application, OrderPizza might be one of the intents. This intent might require the CrustType slot. You specify the valueElicitationPrompt field when you create the CrustType slot. If you have defined a fallback intent the cancel statement will not be sent to the user, the fallback intent is used instead. For more information, see  AMAZON.FallbackIntent. Defaults to None.
        idle_session_ttl_in_seconds(int, optional): The maximum time in seconds that Amazon Lex retains the data gathered in a conversation. A user interaction session remains active for the amount of time specified. If no conversation occurs during this time, the session expires and Amazon Lex deletes any data provided before the timeout. For example, suppose that a user chooses the OrderPizza intent, but gets sidetracked halfway through placing an order. If the user doesn't complete the order within the specified time, Amazon Lex discards the slot information that it gathered, and the user must start over. If you don't include the idleSessionTTLInSeconds element in a PutBot operation request, Amazon Lex uses the default value. This is also true if the request replaces an existing bot. The default is 300 seconds (5 minutes). Defaults to None.
        voice_id(str, optional): The Amazon Polly voice ID that you want Amazon Lex to use for voice interactions with the user. The locale configured for the voice must match the locale of the bot. For more information, see Voices in Amazon Polly in the Amazon Polly Developer Guide. Defaults to None.
        checksum(str, optional): Identifies a specific revision of the $LATEST version. When you create a new bot, leave the checksum field blank. If you specify a checksum you get a BadRequestException exception. When you want to update a bot, set the checksum field to the checksum of the most recent revision of the $LATEST version. If you don't specify the  checksum field, or if the checksum does not match the $LATEST version, you get a PreconditionFailedException exception. Defaults to None.
        process_behavior(str, optional): If you set the processBehavior element to BUILD, Amazon Lex builds the bot so that it can be run. If you set the element to SAVE Amazon Lex saves the bot, but doesn't build it.  If you don't specify this value, the default value is BUILD. Defaults to None.
        locale(str):  Specifies the target locale for the bot. Any intent used in the bot must be compatible with the locale of the bot.  The default is en-US.
        child_directed(bool): For each Amazon Lex bot created with the Amazon Lex Model Building Service, you must specify whether your use of Amazon Lex is related to a website, program, or other application that is directed or targeted, in whole or in part, to children under age 13 and subject to the Children's Online Privacy Protection Act (COPPA) by specifying true or false in the childDirected field. By specifying true in the childDirected field, you confirm that your use of Amazon Lex is related to a website, program, or other application that is directed or targeted, in whole or in part, to children under age 13 and subject to COPPA. By specifying false in the childDirected field, you confirm that your use of Amazon Lex is not related to a website, program, or other application that is directed or targeted, in whole or in part, to children under age 13 and subject to COPPA. You may not specify a default value for the childDirected field that does not accurately reflect whether your use of Amazon Lex is related to a website, program, or other application that is directed or targeted, in whole or in part, to children under age 13 and subject to COPPA. If your use of Amazon Lex relates to a website, program, or other application that is directed in whole or in part, to children under age 13, you must obtain any required verifiable parental consent under COPPA. For information regarding the use of Amazon Lex in connection with websites, programs, or other applications that are directed or targeted, in whole or in part, to children under age 13, see the Amazon Lex FAQ. .
        detect_sentiment(bool, optional): When set to true user utterances are sent to Amazon Comprehend for sentiment analysis. If you don't specify detectSentiment, the default is false. Defaults to None.
        create_version(bool, optional): When set to true a new numbered version of the bot is created. This is the same as calling the CreateBotVersion operation. If you don't specify createVersion, the default is false. Defaults to None.
        tags(List, optional): A list of tags to add to the bot. You can only add tags when you create a bot, you can't use the PutBot operation to update the tags on a bot. To update tags, use the TagResource operation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lex_model.bot.init.put(
                ctx, name=value, locale=value, child_directed=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lex_model.bot.init.put name=value, locale=value, child_directed=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lex-models",
        operation="put_bot",
        op_kwargs={
            "name": name,
            "description": description,
            "intents": intents,
            "enableModelImprovements": enable_model_improvements,
            "nluIntentConfidenceThreshold": nlu_intent_confidence_threshold,
            "clarificationPrompt": clarification_prompt,
            "abortStatement": abort_statement,
            "idleSessionTTLInSeconds": idle_session_ttl_in_seconds,
            "voiceId": voice_id,
            "checksum": checksum,
            "processBehavior": process_behavior,
            "locale": locale,
            "childDirected": child_directed,
            "detectSentiment": detect_sentiment,
            "createVersion": create_version,
            "tags": tags,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub, ctx, bulk_deployment_id: str, max_results: str = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Gets a paginated list of the deployments that have been started in a bulk deployment operation, and their current deployment status.

    Args:
        bulk_deployment_id(str): The ID of the bulk deployment.
        max_results(str, optional): The maximum number of results to be returned per request. Defaults to None.
        next_token(str, optional): The token for the next set of results, or ''null'' if there are no additional results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.greengrass.bulk_deployment.detailed_report.list_all(
                ctx, bulk_deployment_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.greengrass.bulk_deployment.detailed_report.list_all bulk_deployment_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="greengrass",
        operation="list_bulk_deployment_detailed_reports",
        op_kwargs={
            "BulkDeploymentId": bulk_deployment_id,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx, arn: str) -> Dict:
    r"""
    **Autogenerated function**

     Deletes a report.

    Args:
        arn(str):  The ARN of the report to delete. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codebuild.report.init.delete(ctx, arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codebuild.report.init.delete arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="codebuild", operation="delete_report", op_kwargs={"arn": arn}
    )


async def list_all(
    hub,
    ctx,
    sort_order: str = None,
    next_token: str = None,
    max_results: int = None,
    filter_: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Returns a list of ARNs for the reports in the current AWS account.

    Args:
        sort_order(str, optional):  Specifies the sort order for the list of returned reports. Valid values are:     ASCENDING: return reports in chronological order based on their creation date.     DESCENDING: return reports in the reverse chronological order based on their creation date.   . Defaults to None.
        next_token(str, optional):  During a previous call, the maximum number of items that can be returned is the value specified in maxResults. If there more items in the list, then a unique string called a nextToken is returned. To get the next batch of items in the list, call this operation again, adding the next token to the call. To get all of the items in the list, keep calling this operation with each subsequent next token that is returned, until no more next tokens are returned. . Defaults to None.
        max_results(int, optional):  The maximum number of paginated reports returned per response. Use nextToken to iterate pages in the list of returned Report objects. The default value is 100. . Defaults to None.
        filter_(Dict, optional):  A ReportFilter object used to filter the returned reports. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codebuild.report.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codebuild.report.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codebuild",
        operation="list_reports",
        op_kwargs={
            "sortOrder": sort_order,
            "nextToken": next_token,
            "maxResults": max_results,
            "filter": filter_,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    gateway_arn: str,
    tape_size_in_bytes: int,
    tape_barcode: str,
    kms_encrypted: bool = None,
    kms_key: str = None,
    pool_id: str = None,
    worm: bool = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a virtual tape by using your own barcode. You write data to the virtual tape and then archive the tape. A barcode is unique and cannot be reused if it has already been used on a tape. This applies to barcodes used on deleted tapes. This operation is only supported in the tape gateway type.  Cache storage must be allocated to the gateway before you can create a virtual tape. Use the AddCache operation to add cache storage to a gateway.

    Args:
        gateway_arn(str): The unique Amazon Resource Name (ARN) that represents the gateway to associate the virtual tape with. Use the ListGateways operation to return a list of gateways for your account and Region.
        tape_size_in_bytes(int): The size, in bytes, of the virtual tape that you want to create.  The size must be aligned by gigabyte (1024*1024*1024 bytes). .
        tape_barcode(str): The barcode that you want to assign to the tape.  Barcodes cannot be reused. This includes barcodes used for tapes that have been deleted. .
        kms_encrypted(bool, optional): Set to true to use Amazon S3 server-side encryption with your own KMS key, or false to use a key managed by Amazon S3. Optional. Valid Values: true | false . Defaults to None.
        kms_key(str, optional): The Amazon Resource Name (ARN) of a symmetric customer master key (CMK) used for Amazon S3 server-side encryption. Storage Gateway does not support asymmetric CMKs. This value can only be set when KMSEncrypted is true. Optional. Defaults to None.
        pool_id(str, optional): The ID of the pool that you want to add your tape to for archiving. The tape in this pool is archived in the S3 storage class that is associated with the pool. When you use your backup application to eject the tape, the tape is archived directly into the storage class (S3 Glacier or S3 Deep Archive) that corresponds to the pool. Valid Values: GLACIER | DEEP_ARCHIVE . Defaults to None.
        worm(bool, optional): Set to TRUE if the tape you are creating is to be configured as a write-once-read-many (WORM) tape. Defaults to None.
        tags(List, optional): A list of up to 50 tags that can be assigned to a virtual tape that has a barcode. Each tag is a key-value pair.  Valid characters for key and value are letters, spaces, and numbers representable in UTF-8 format, and the following special characters: + - = . _ : / @. The maximum length of a tag's key is 128 characters, and the maximum length for a tag's value is 256. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.storagegateway.tape.with_barcode.create(
                ctx, gateway_arn=value, tape_size_in_bytes=value, tape_barcode=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.storagegateway.tape.with_barcode.create gateway_arn=value, tape_size_in_bytes=value, tape_barcode=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="storagegateway",
        operation="create_tape_with_barcode",
        op_kwargs={
            "GatewayARN": gateway_arn,
            "TapeSizeInBytes": tape_size_in_bytes,
            "TapeBarcode": tape_barcode,
            "KMSEncrypted": kms_encrypted,
            "KMSKey": kms_key,
            "PoolId": pool_id,
            "Worm": worm,
            "Tags": tags,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def delete(hub, ctx, queue_url: str, entries: List) -> Dict:
    r"""
    **Autogenerated function**

    Deletes up to ten messages from the specified queue. This is a batch version of  DeleteMessage. The result of the action on each message is reported individually in the response.  Because the batch request can result in a combination of successful and unsuccessful actions, you should check for batch errors even when the call returns an HTTP status code of 200.  Some actions take lists of parameters. These lists are specified using the param.n notation. Values of n are integers starting from 1. For example, a parameter list with two elements looks like this:  &AttributeName.1=first   &AttributeName.2=second

    Args:
        queue_url(str): The URL of the Amazon SQS queue from which messages are deleted. Queue URLs and names are case-sensitive.
        entries(List): A list of receipt handles for the messages to be deleted.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sqs.message.batch.delete(ctx, queue_url=value, entries=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sqs.message.batch.delete queue_url=value, entries=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sqs",
        operation="delete_message_batch",
        op_kwargs={"QueueUrl": queue_url, "Entries": entries},
    )


async def send(hub, ctx, queue_url: str, entries: List) -> Dict:
    r"""
    **Autogenerated function**

    Delivers up to ten messages to the specified queue. This is a batch version of  SendMessage. For a FIFO queue, multiple messages within a single batch are enqueued in the order they are sent. The result of sending each message is reported individually in the response. Because the batch request can result in a combination of successful and unsuccessful actions, you should check for batch errors even when the call returns an HTTP status code of 200. The maximum allowed individual message size and the maximum total payload size (the sum of the individual lengths of all of the batched messages) are both 256 KB (262,144 bytes).  A message can include only XML, JSON, and unformatted text. The following Unicode characters are allowed:  #x9 | #xA | #xD | #x20 to #xD7FF | #xE000 to #xFFFD | #x10000 to #x10FFFF  Any characters not included in this list will be rejected. For more information, see the W3C specification for characters.  If you don't specify the DelaySeconds parameter for an entry, Amazon SQS uses the default value for the queue. Some actions take lists of parameters. These lists are specified using the param.n notation. Values of n are integers starting from 1. For example, a parameter list with two elements looks like this:  &AttributeName.1=first   &AttributeName.2=second

    Args:
        queue_url(str): The URL of the Amazon SQS queue to which batched messages are sent. Queue URLs and names are case-sensitive.
        entries(List): A list of  SendMessageBatchRequestEntry  items.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sqs.message.batch.send(ctx, queue_url=value, entries=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sqs.message.batch.send queue_url=value, entries=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sqs",
        operation="send_message_batch",
        op_kwargs={"QueueUrl": queue_url, "Entries": entries},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def remove(
    hub,
    ctx,
    thing_group_name: str = None,
    thing_group_arn: str = None,
    thing_name: str = None,
    thing_arn: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Remove the specified thing from the specified group. You must specify either a thingGroupArn or a thingGroupName to identify the thing group and either a thingArn or a thingName to identify the thing to remove from the thing group.

    Args:
        thing_group_name(str, optional): The group name. Defaults to None.
        thing_group_arn(str, optional): The group ARN. Defaults to None.
        thing_name(str, optional): The name of the thing to remove from the group. Defaults to None.
        thing_arn(str, optional): The ARN of the thing to remove from the group. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.thing.from_.thing_group.remove(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.thing.from_.thing_group.remove
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="remove_thing_from_thing_group",
        op_kwargs={
            "thingGroupName": thing_group_name,
            "thingGroupArn": thing_group_arn,
            "thingName": thing_name,
            "thingArn": thing_arn,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub, ctx, name: str, require_encryption: bool, aws_region: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an Amazon Chime Voice Connector under the administrator's AWS account. You can choose to create an Amazon Chime Voice Connector in a specific AWS Region.  Enabling CreateVoiceConnectorRequest$RequireEncryption configures your Amazon Chime Voice Connector to use TLS transport for SIP signaling and Secure RTP (SRTP) for media. Inbound calls use TLS transport, and unencrypted outbound calls are blocked.

    Args:
        name(str): The name of the Amazon Chime Voice Connector.
        aws_region(str, optional):  The AWS Region in which the Amazon Chime Voice Connector is created. Default value: us-east-1 . . Defaults to None.
        require_encryption(bool): When enabled, requires encryption for the Amazon Chime Voice Connector.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.voice_connector.init.create(
                ctx, name=value, require_encryption=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.voice_connector.init.create name=value, require_encryption=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="create_voice_connector",
        op_kwargs={
            "Name": name,
            "AwsRegion": aws_region,
            "RequireEncryption": require_encryption,
        },
    )


async def delete(hub, ctx, voice_connector_id: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified Amazon Chime Voice Connector. Any phone numbers associated with the Amazon Chime Voice Connector must be disassociated from it before it can be deleted.

    Args:
        voice_connector_id(str): The Amazon Chime Voice Connector ID.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.voice_connector.init.delete(ctx, voice_connector_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.voice_connector.init.delete voice_connector_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="delete_voice_connector",
        op_kwargs={"VoiceConnectorId": voice_connector_id},
    )


async def get(hub, ctx, voice_connector_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves details for the specified Amazon Chime Voice Connector, such as timestamps,name, outbound host, and encryption requirements.

    Args:
        voice_connector_id(str): The Amazon Chime Voice Connector ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.voice_connector.init.get(ctx, voice_connector_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.voice_connector.init.get voice_connector_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="get_voice_connector",
        op_kwargs={"VoiceConnectorId": voice_connector_id},
    )


async def list_all(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists the Amazon Chime Voice Connectors for the administrator's AWS account.

    Args:
        next_token(str, optional): The token to use to retrieve the next page of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return in a single call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.voice_connector.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.voice_connector.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="list_voice_connectors",
        op_kwargs={"NextToken": next_token, "MaxResults": max_results},
    )


async def update(
    hub, ctx, voice_connector_id: str, name: str, require_encryption: bool
) -> Dict:
    r"""
    **Autogenerated function**

    Updates details for the specified Amazon Chime Voice Connector.

    Args:
        voice_connector_id(str): The Amazon Chime Voice Connector ID.
        name(str): The name of the Amazon Chime Voice Connector.
        require_encryption(bool): When enabled, requires encryption for the Amazon Chime Voice Connector.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.voice_connector.init.update(
                ctx, voice_connector_id=value, name=value, require_encryption=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.voice_connector.init.update voice_connector_id=value, name=value, require_encryption=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="update_voice_connector",
        op_kwargs={
            "VoiceConnectorId": voice_connector_id,
            "Name": name,
            "RequireEncryption": require_encryption,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def activate(hub, ctx, contact_channel_id: str, activation_code: str) -> Dict:
    r"""
    **Autogenerated function**

    Activates a contact's contact channel. Incident Manager can't engage a contact until the contact channel has been activated.

    Args:
        contact_channel_id(str): The Amazon Resource Name (ARN) of the contact channel.
        activation_code(str): The code sent to the contact channel when it was created in the contact. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm_contact.contact.channel.activate(
                ctx, contact_channel_id=value, activation_code=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm_contact.contact.channel.activate contact_channel_id=value, activation_code=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm-contacts",
        operation="activate_contact_channel",
        op_kwargs={
            "ContactChannelId": contact_channel_id,
            "ActivationCode": activation_code,
        },
    )


async def create(
    hub,
    ctx,
    contact_id: str,
    name: str,
    type_: str,
    delivery_address: Dict,
    defer_activation: bool = None,
    idempotency_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    A contact channel is the method that Incident Manager uses to engage your contact.

    Args:
        contact_id(str): The Amazon Resource Name (ARN) of the contact you are adding the contact channel to.
        name(str): The name of the contact channel.
        type_(str): Incident Manager supports three types of contact channels:    SMS     VOICE     EMAIL   .
        delivery_address(Dict): The details that Incident Manager uses when trying to engage the contact channel. The format is dependent on the type of the contact channel. The following are the expected formats:   SMS - '+' followed by the country code and phone number   VOICE - '+' followed by the country code and phone number   EMAIL - any standard email format  .
        defer_activation(bool, optional): If you want to activate the channel at a later time, you can choose to defer activation. Incident Manager can't engage your contact channel until it has been activated. Defaults to None.
        idempotency_token(str, optional): A token ensuring that the action is called only once with the specified details. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm_contact.contact.channel.create(
                ctx, contact_id=value, name=value, type_=value, delivery_address=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm_contact.contact.channel.create contact_id=value, name=value, type_=value, delivery_address=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm-contacts",
        operation="create_contact_channel",
        op_kwargs={
            "ContactId": contact_id,
            "Name": name,
            "Type": type_,
            "DeliveryAddress": delivery_address,
            "DeferActivation": defer_activation,
            "IdempotencyToken": idempotency_token,
        },
    )


async def deactivate(hub, ctx, contact_channel_id: str) -> Dict:
    r"""
    **Autogenerated function**

    To no longer receive Incident Manager engagements to a contact channel, you can deactivate the channel.

    Args:
        contact_channel_id(str): The Amazon Resource Name (ARN) of the contact channel you're deactivating.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm_contact.contact.channel.deactivate(
                ctx, contact_channel_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm_contact.contact.channel.deactivate contact_channel_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm-contacts",
        operation="deactivate_contact_channel",
        op_kwargs={"ContactChannelId": contact_channel_id},
    )


async def delete(hub, ctx, contact_channel_id: str) -> Dict:
    r"""
    **Autogenerated function**

    To no longer receive engagements on a contact channel, you can delete the channel from a contact. Deleting the contact channel removes it from the contact's engagement plan. If you delete the only contact channel for a contact, you won't be able to engage that contact during an incident.

    Args:
        contact_channel_id(str): The Amazon Resource Name (ARN) of the contact channel.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm_contact.contact.channel.delete(
                ctx, contact_channel_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm_contact.contact.channel.delete contact_channel_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm-contacts",
        operation="delete_contact_channel",
        op_kwargs={"ContactChannelId": contact_channel_id},
    )


async def get(hub, ctx, contact_channel_id: str) -> Dict:
    r"""
    **Autogenerated function**

    List details about a specific contact channel.

    Args:
        contact_channel_id(str): The Amazon Resource Name (ARN) of the contact channel you want information about.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm_contact.contact.channel.get(ctx, contact_channel_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm_contact.contact.channel.get contact_channel_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm-contacts",
        operation="get_contact_channel",
        op_kwargs={"ContactChannelId": contact_channel_id},
    )


async def list_all(
    hub, ctx, contact_id: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists all contact channels for the specified contact.

    Args:
        contact_id(str): The Amazon Resource Name (ARN) of the contact. .
        next_token(str, optional): The pagination token to continue to the next page of results. Defaults to None.
        max_results(int, optional): The maximum number of contact channels per page. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm_contact.contact.channel.list_all(ctx, contact_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm_contact.contact.channel.list_all contact_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm-contacts",
        operation="list_contact_channels",
        op_kwargs={
            "ContactId": contact_id,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def update(
    hub, ctx, contact_channel_id: str, name: str = None, delivery_address: Dict = None
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a contact's contact channel.

    Args:
        contact_channel_id(str): The Amazon Resource Name (ARN) of the contact channel you want to update.
        name(str, optional): The name of the contact channel. Defaults to None.
        delivery_address(Dict, optional): The details that Incident Manager uses when trying to engage the contact channel. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm_contact.contact.channel.update(
                ctx, contact_channel_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm_contact.contact.channel.update contact_channel_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm-contacts",
        operation="update_contact_channel",
        op_kwargs={
            "ContactChannelId": contact_channel_id,
            "Name": name,
            "DeliveryAddress": delivery_address,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def disable(hub, ctx, domain_name: str) -> Dict:
    r"""
    **Autogenerated function**

    This operation disables automatic renewal of domain registration for the specified domain.

    Args:
        domain_name(str): The name of the domain that you want to disable automatic renewal for.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53domain.domain.auto_renew.disable(ctx, domain_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53domain.domain.auto_renew.disable domain_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53domains",
        operation="disable_domain_auto_renew",
        op_kwargs={"DomainName": domain_name},
    )


async def enable(hub, ctx, domain_name: str) -> Dict:
    r"""
    **Autogenerated function**

    This operation configures Amazon Route 53 to automatically renew the specified domain before the domain registration expires. The cost of renewing your domain registration is billed to your AWS account. The period during which you can renew a domain name varies by TLD. For a list of TLDs and their renewal policies, see Domains That You Can Register with Amazon Route 53 in the Amazon Route 53 Developer Guide. Route 53 requires that you renew before the end of the renewal period so we can complete processing before the deadline.

    Args:
        domain_name(str): The name of the domain that you want to enable automatic renewal for.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53domain.domain.auto_renew.enable(ctx, domain_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53domain.domain.auto_renew.enable domain_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53domains",
        operation="enable_domain_auto_renew",
        op_kwargs={"DomainName": domain_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx, phone_number: str, language_code: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Adds a destination phone number to an account in the SMS sandbox and sends a one-time password (OTP) to that phone number. When you start using Amazon SNS to send SMS messages, your account is in the SMS sandbox. The SMS sandbox provides a safe environment for you to try Amazon SNS features without risking your reputation as an SMS sender. While your account is in the SMS sandbox, you can use all of the features of Amazon SNS. However, you can send SMS messages only to verified destination phone numbers. For more information, including how to move out of the sandbox to send messages without restrictions, see SMS sandbox in the Amazon SNS Developer Guide.

    Args:
        phone_number(str): The destination phone number to verify. On verification, Amazon SNS adds this phone number to the list of verified phone numbers that you can send SMS messages to.
        language_code(str, optional): The language to use for sending the OTP. The default value is en-US. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sns.sms.sandbox.phone_number.create(ctx, phone_number=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sns.sms.sandbox.phone_number.create phone_number=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sns",
        operation="create_sms_sandbox_phone_number",
        op_kwargs={"PhoneNumber": phone_number, "LanguageCode": language_code},
    )


async def delete(hub, ctx, phone_number: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an account's verified or pending phone number from the SMS sandbox. When you start using Amazon SNS to send SMS messages, your account is in the SMS sandbox. The SMS sandbox provides a safe environment for you to try Amazon SNS features without risking your reputation as an SMS sender. While your account is in the SMS sandbox, you can use all of the features of Amazon SNS. However, you can send SMS messages only to verified destination phone numbers. For more information, including how to move out of the sandbox to send messages without restrictions, see SMS sandbox in the Amazon SNS Developer Guide.

    Args:
        phone_number(str): The destination phone number to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sns.sms.sandbox.phone_number.delete(ctx, phone_number=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sns.sms.sandbox.phone_number.delete phone_number=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sns",
        operation="delete_sms_sandbox_phone_number",
        op_kwargs={"PhoneNumber": phone_number},
    )


async def list_all(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists the calling account's current verified and pending destination phone numbers in the SMS sandbox. When you start using Amazon SNS to send SMS messages, your account is in the SMS sandbox. The SMS sandbox provides a safe environment for you to try Amazon SNS features without risking your reputation as an SMS sender. While your account is in the SMS sandbox, you can use all of the features of Amazon SNS. However, you can send SMS messages only to verified destination phone numbers. For more information, including how to move out of the sandbox to send messages without restrictions, see SMS sandbox in the Amazon SNS Developer Guide.

    Args:
        next_token(str, optional): Token that the previous ListSMSSandboxPhoneNumbersInput request returns. Defaults to None.
        max_results(int, optional): The maximum number of phone numbers to return. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sns.sms.sandbox.phone_number.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sns.sms.sandbox.phone_number.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sns",
        operation="list_sms_sandbox_phone_numbers",
        op_kwargs={"NextToken": next_token, "MaxResults": max_results},
    )


async def verify(hub, ctx, phone_number: str, one_time_password: str) -> Dict:
    r"""
    **Autogenerated function**

    Verifies a destination phone number with a one-time password (OTP) for the calling account. When you start using Amazon SNS to send SMS messages, your account is in the SMS sandbox. The SMS sandbox provides a safe environment for you to try Amazon SNS features without risking your reputation as an SMS sender. While your account is in the SMS sandbox, you can use all of the features of Amazon SNS. However, you can send SMS messages only to verified destination phone numbers. For more information, including how to move out of the sandbox to send messages without restrictions, see SMS sandbox in the Amazon SNS Developer Guide.

    Args:
        phone_number(str): The destination phone number to verify.
        one_time_password(str): The OTP sent to the destination number from the CreateSMSSandBoxPhoneNumber call.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sns.sms.sandbox.phone_number.verify(
                ctx, phone_number=value, one_time_password=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sns.sms.sandbox.phone_number.verify phone_number=value, one_time_password=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sns",
        operation="verify_sms_sandbox_phone_number",
        op_kwargs={"PhoneNumber": phone_number, "OneTimePassword": one_time_password},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(
    hub,
    ctx,
    transit_gateway_attachment_ids: List = None,
    filters: List = None,
    max_results: int = None,
    next_token: str = None,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes one or more attachments between resources and transit gateways. By default, all attachments are described. Alternatively, you can filter the results by attachment ID, attachment state, resource ID, or resource owner.

    Args:
        transit_gateway_attachment_ids(List, optional): The IDs of the attachments. Defaults to None.
        filters(List, optional): One or more filters. The possible values are:    association.state - The state of the association (associating | associated | disassociating).    association.transit-gateway-route-table-id - The ID of the route table for the transit gateway.    resource-id - The ID of the resource.    resource-owner-id - The ID of the AWS account that owns the resource.    resource-type - The resource type. Valid values are vpc | vpn | direct-connect-gateway | peering | connect.    state - The state of the attachment. Valid values are available | deleted | deleting | failed | failing | initiatingRequest | modifying | pendingAcceptance | pending | rollingBack | rejected | rejecting.    transit-gateway-attachment-id - The ID of the attachment.    transit-gateway-id - The ID of the transit gateway.    transit-gateway-owner-id - The ID of the AWS account that owns the transit gateway.  . Defaults to None.
        max_results(int, optional): The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value. Defaults to None.
        next_token(str, optional): The token for the next page of results. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.transit_gateway.attachment.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.transit_gateway.attachment.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_transit_gateway_attachments",
        op_kwargs={
            "TransitGatewayAttachmentIds": transit_gateway_attachment_ids,
            "Filters": filters,
            "MaxResults": max_results,
            "NextToken": next_token,
            "DryRun": dry_run,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(
    hub,
    ctx,
    filters: List = None,
    max_results: int = None,
    next_token: str = None,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the state of fast snapshot restores for your snapshots.

    Args:
        filters(List, optional): The filters. The possible values are:    availability-zone: The Availability Zone of the snapshot.    owner-id: The ID of the Amazon Web Services account that enabled fast snapshot restore on the snapshot.    snapshot-id: The ID of the snapshot.    state: The state of fast snapshot restores for the snapshot (enabling | optimizing | enabled | disabling | disabled).  . Defaults to None.
        max_results(int, optional): The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value. Defaults to None.
        next_token(str, optional): The token for the next page of results. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.fast_snapshot_restore.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.fast_snapshot_restore.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_fast_snapshot_restores",
        op_kwargs={
            "Filters": filters,
            "MaxResults": max_results,
            "NextToken": next_token,
            "DryRun": dry_run,
        },
    )


async def disable(
    hub, ctx, availability_zones: List, source_snapshot_ids: List, dry_run: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Disables fast snapshot restores for the specified snapshots in the specified Availability Zones.

    Args:
        availability_zones(List): One or more Availability Zones. For example, us-east-2a.
        source_snapshot_ids(List): The IDs of one or more snapshots. For example, snap-1234567890abcdef0.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.fast_snapshot_restore.disable(
                ctx, availability_zones=value, source_snapshot_ids=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.fast_snapshot_restore.disable availability_zones=value, source_snapshot_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="disable_fast_snapshot_restores",
        op_kwargs={
            "AvailabilityZones": availability_zones,
            "SourceSnapshotIds": source_snapshot_ids,
            "DryRun": dry_run,
        },
    )


async def enable(
    hub, ctx, availability_zones: List, source_snapshot_ids: List, dry_run: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Enables fast snapshot restores for the specified snapshots in the specified Availability Zones. You get the full benefit of fast snapshot restores after they enter the enabled state. To get the current state of fast snapshot restores, use DescribeFastSnapshotRestores. To disable fast snapshot restores, use DisableFastSnapshotRestores. For more information, see Amazon EBS fast snapshot restore in the Amazon Elastic Compute Cloud User Guide.

    Args:
        availability_zones(List): One or more Availability Zones. For example, us-east-2a.
        source_snapshot_ids(List): The IDs of one or more snapshots. For example, snap-1234567890abcdef0. You can specify a snapshot that was shared with you from another Amazon Web Services account.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.fast_snapshot_restore.enable(
                ctx, availability_zones=value, source_snapshot_ids=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.fast_snapshot_restore.enable availability_zones=value, source_snapshot_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="enable_fast_snapshot_restores",
        op_kwargs={
            "AvailabilityZones": availability_zones,
            "SourceSnapshotIds": source_snapshot_ids,
            "DryRun": dry_run,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(hub, ctx, catalog_id: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the list of the data lake administrators of a Lake Formation-managed data lake.

    Args:
        catalog_id(str, optional): The identifier for the Data Catalog. By default, the account ID. The Data Catalog is the persistent metadata store. It contains database definitions, table definitions, and other control information to manage your AWS Lake Formation environment. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lakeformation.data.lake_setting.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lakeformation.data.lake_setting.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lakeformation",
        operation="get_data_lake_settings",
        op_kwargs={"CatalogId": catalog_id},
    )


async def put_multiple(
    hub, ctx, data_lake_settings: Dict, catalog_id: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Sets the list of data lake administrators who have admin privileges on all resources managed by Lake Formation. For more information on admin privileges, see Granting Lake Formation Permissions. This API replaces the current list of data lake admins with the new list being passed. To add an admin, fetch the current list and add the new admin to that list and pass that list in this API.

    Args:
        catalog_id(str, optional): The identifier for the Data Catalog. By default, the account ID. The Data Catalog is the persistent metadata store. It contains database definitions, table definitions, and other control information to manage your AWS Lake Formation environment. . Defaults to None.
        data_lake_settings(Dict): A structure representing a list of AWS Lake Formation principals designated as data lake administrators.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lakeformation.data.lake_setting.put_multiple(
                ctx, data_lake_settings=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lakeformation.data.lake_setting.put_multiple data_lake_settings=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lakeformation",
        operation="put_data_lake_settings",
        op_kwargs={"CatalogId": catalog_id, "DataLakeSettings": data_lake_settings},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    schema_arn: str,
    name: str,
    attributes: List = None,
    object_type: str = None,
    facet_style: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new Facet in a schema. Facet creation is allowed only in development or applied schemas.

    Args:
        schema_arn(str): The schema ARN in which the new Facet will be created. For more information, see arns.
        name(str): The name of the Facet, which is unique for a given schema.
        attributes(List, optional): The attributes that are associated with the Facet. Defaults to None.
        object_type(str, optional): Specifies whether a given object created from this facet is of type node, leaf node, policy or index.   Node: Can have multiple children but one parent.     Leaf node: Cannot have children but can have multiple parents.     Policy: Allows you to store a policy document and policy type. For more information, see Policies.     Index: Can be created with the Index API.  . Defaults to None.
        facet_style(str, optional): There are two different styles that you can define on any given facet, Static and Dynamic. For static facets, all attributes must be defined in the schema. For dynamic facets, attributes can be defined during data plane operations. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.clouddirectory.facet.init.create(
                ctx, schema_arn=value, name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.clouddirectory.facet.init.create schema_arn=value, name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="clouddirectory",
        operation="create_facet",
        op_kwargs={
            "SchemaArn": schema_arn,
            "Name": name,
            "Attributes": attributes,
            "ObjectType": object_type,
            "FacetStyle": facet_style,
        },
    )


async def delete(hub, ctx, schema_arn: str, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a given Facet. All attributes and Rules that are associated with the facet will be deleted. Only development schema facets are allowed deletion.

    Args:
        schema_arn(str): The Amazon Resource Name (ARN) that is associated with the Facet. For more information, see arns.
        name(str): The name of the facet to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.clouddirectory.facet.init.delete(
                ctx, schema_arn=value, name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.clouddirectory.facet.init.delete schema_arn=value, name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="clouddirectory",
        operation="delete_facet",
        op_kwargs={"SchemaArn": schema_arn, "Name": name},
    )


async def get(hub, ctx, schema_arn: str, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets details of the Facet, such as facet name, attributes, Rules, or ObjectType. You can call this on all kinds of schema facets -- published, development, or applied.

    Args:
        schema_arn(str): The Amazon Resource Name (ARN) that is associated with the Facet. For more information, see arns.
        name(str): The name of the facet to retrieve.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.clouddirectory.facet.init.get(ctx, schema_arn=value, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.clouddirectory.facet.init.get schema_arn=value, name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="clouddirectory",
        operation="get_facet",
        op_kwargs={"SchemaArn": schema_arn, "Name": name},
    )


async def update(
    hub,
    ctx,
    schema_arn: str,
    name: str,
    attribute_updates: List = None,
    object_type: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Does the following:   Adds new Attributes, Rules, or ObjectTypes.   Updates existing Attributes, Rules, or ObjectTypes.   Deletes existing Attributes, Rules, or ObjectTypes.

    Args:
        schema_arn(str): The Amazon Resource Name (ARN) that is associated with the Facet. For more information, see arns.
        name(str): The name of the facet.
        attribute_updates(List, optional): List of attributes that need to be updated in a given schema Facet. Each attribute is followed by AttributeAction, which specifies the type of update operation to perform. . Defaults to None.
        object_type(str, optional): The object type that is associated with the facet. See CreateFacetRequest$ObjectType for more details. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.clouddirectory.facet.init.update(
                ctx, schema_arn=value, name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.clouddirectory.facet.init.update schema_arn=value, name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="clouddirectory",
        operation="update_facet",
        op_kwargs={
            "SchemaArn": schema_arn,
            "Name": name,
            "AttributeUpdates": attribute_updates,
            "ObjectType": object_type,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(hub, ctx, marker: str = None, max_items: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists the account alias associated with the account (Note: you can have only one). For information about using an account alias, see Using an alias for your account ID in the IAM User Guide.

    Args:
        marker(str, optional): Use this parameter only when paginating results and only after you receive a response indicating that the results are truncated. Set it to the value of the Marker element in the response that you received to indicate where the next call should start. Defaults to None.
        max_items(int, optional): Use this only when paginating results to indicate the maximum number of items you want in the response. If additional items exist beyond the maximum you specify, the IsTruncated response element is true. If you do not include this parameter, the number of items defaults to 100. Note that IAM might return fewer results, even when there are more results available. In that case, the IsTruncated response element returns true, and Marker contains a value to include in the subsequent call that tells the service where to continue from. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.account.aliase.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.account.aliase.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="list_account_aliases",
        op_kwargs={"Marker": marker, "MaxItems": max_items},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx, finding_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about a single audit finding. Properties include the reason for noncompliance, the severity of the issue, and the start time when the audit that returned the finding.

    Args:
        finding_id(str): A unique identifier for a single audit finding. You can use this identifier to apply mitigation actions to the finding.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.audit.finding.describe(ctx, finding_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.audit.finding.describe finding_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="describe_audit_finding",
        op_kwargs={"findingId": finding_id},
    )


async def list_all(
    hub,
    ctx,
    task_id: str = None,
    check_name: str = None,
    resource_identifier: Dict = None,
    max_results: int = None,
    next_token: str = None,
    start_time: str = None,
    end_time: str = None,
    list_suppressed_findings: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the findings (results) of a Device Defender audit or of the audits performed during a specified time period. (Findings are retained for 90 days.)

    Args:
        task_id(str, optional): A filter to limit results to the audit with the specified ID. You must specify either the taskId or the startTime and endTime, but not both. Defaults to None.
        check_name(str, optional): A filter to limit results to the findings for the specified audit check. Defaults to None.
        resource_identifier(Dict, optional): Information identifying the noncompliant resource. Defaults to None.
        max_results(int, optional): The maximum number of results to return at one time. The default is 25. Defaults to None.
        next_token(str, optional): The token for the next set of results. Defaults to None.
        start_time(str, optional): A filter to limit results to those found after the specified time. You must specify either the startTime and endTime or the taskId, but not both. Defaults to None.
        end_time(str, optional): A filter to limit results to those found before the specified time. You must specify either the startTime and endTime or the taskId, but not both. Defaults to None.
        list_suppressed_findings(bool, optional):  Boolean flag indicating whether only the suppressed findings or the unsuppressed findings should be listed. If this parameter isn't provided, the response will list both suppressed and unsuppressed findings. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.audit.finding.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.audit.finding.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="list_audit_findings",
        op_kwargs={
            "taskId": task_id,
            "checkName": check_name,
            "resourceIdentifier": resource_identifier,
            "maxResults": max_results,
            "nextToken": next_token,
            "startTime": start_time,
            "endTime": end_time,
            "listSuppressedFindings": list_suppressed_findings,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, function_name: str, qualifier: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns the resource-based IAM policy for a function, version, or alias.

    Args:
        function_name(str): The name of the Lambda function, version, or alias.  Name formats     Function name - my-function (name-only), my-function:v1 (with alias).    Function ARN - arn:aws:lambda:us-west-2:123456789012:function:my-function.    Partial ARN - 123456789012:function:my-function.   You can append a version number or alias to any of the formats. The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
        qualifier(str, optional): Specify a version or alias to get the policy for that resource. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lambda_.policy.get(ctx, function_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lambda_.policy.get function_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lambda",
        operation="get_policy",
        op_kwargs={"FunctionName": function_name, "Qualifier": qualifier},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"set_": "set"}


async def set_(hub, ctx, gateway_arn: str, local_console_password: str) -> Dict:
    r"""
    **Autogenerated function**

    Sets the password for your VM local console. When you log in to the local console for the first time, you log in to the VM with the default credentials. We recommend that you set a new password. You don't need to know the default password to set a new password.

    Args:
        gateway_arn(str): The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and Region.
        local_console_password(str): The password you want to set for your VM local console.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.storagegateway.local.console_password.set(
                ctx, gateway_arn=value, local_console_password=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.storagegateway.local.console_password.set gateway_arn=value, local_console_password=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="storagegateway",
        operation="set_local_console_password",
        op_kwargs={
            "GatewayARN": gateway_arn,
            "LocalConsolePassword": local_console_password,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe(
    hub,
    ctx,
    window_id: str = None,
    targets: List = None,
    resource_type: str = None,
    filters: List = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves information about upcoming executions of a maintenance window.

    Args:
        window_id(str, optional): The ID of the maintenance window to retrieve information about. Defaults to None.
        targets(List, optional): The instance ID or key-value pair to retrieve information about. Defaults to None.
        resource_type(str, optional): The type of resource you want to retrieve information about. For example, INSTANCE. Defaults to None.
        filters(List, optional): Filters used to limit the range of results. For example, you can limit maintenance window executions to only those scheduled before or after a certain date and time. Defaults to None.
        max_results(int, optional): The maximum number of items to return for this call. The call also returns a token that you can specify in a subsequent call to get the next set of results. Defaults to None.
        next_token(str, optional): The token for the next set of items to return. (You received this token from a previous call.). Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.maintenance_window.schedule.describe(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.maintenance_window.schedule.describe
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="describe_maintenance_window_schedule",
        op_kwargs={
            "WindowId": window_id,
            "Targets": targets,
            "ResourceType": resource_type,
            "Filters": filters,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def put_multiple(
    hub, ctx, email_identity: str, email_forwarding_enabled: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Used to enable or disable feedback forwarding for an identity. This setting determines what happens when an identity is used to send an email that results in a bounce or complaint event. When you enable feedback forwarding, Amazon Pinpoint sends you email notifications when bounce or complaint events occur. Amazon Pinpoint sends this notification to the address that you specified in the Return-Path header of the original email. When you disable feedback forwarding, Amazon Pinpoint sends notifications through other mechanisms, such as by notifying an Amazon SNS topic. You're required to have a method of tracking bounces and complaints. If you haven't set up another mechanism for receiving bounce or complaint notifications, Amazon Pinpoint sends an email notification when these events occur (even if this setting is disabled).

    Args:
        email_identity(str): The email identity that you want to configure bounce and complaint feedback forwarding for.
        email_forwarding_enabled(bool, optional): Sets the feedback forwarding configuration for the identity. If the value is true, Amazon Pinpoint sends you email notifications when bounce or complaint events occur. Amazon Pinpoint sends this notification to the address that you specified in the Return-Path header of the original email. When you set this value to false, Amazon Pinpoint sends notifications through other mechanisms, such as by notifying an Amazon SNS topic or another event destination. You're required to have a method of tracking bounces and complaints. If you haven't set up another mechanism for receiving bounce or complaint notifications, Amazon Pinpoint sends an email notification when these events occur (even if this setting is disabled). Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.pinpoint_email.email.identity.feedback_attribute.put_multiple(
                ctx, email_identity=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.pinpoint_email.email.identity.feedback_attribute.put_multiple email_identity=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="pinpoint-email",
        operation="put_email_identity_feedback_attributes",
        op_kwargs={
            "EmailIdentity": email_identity,
            "EmailForwardingEnabled": email_forwarding_enabled,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe(
    hub,
    ctx,
    alarm_name: str = None,
    alarm_types: List = None,
    history_item_type: str = None,
    start_date: str = None,
    end_date: str = None,
    max_records: int = None,
    next_token: str = None,
    scan_by: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the history for the specified alarm. You can filter the results by date range or item type. If an alarm name is not specified, the histories for either all metric alarms or all composite alarms are returned. CloudWatch retains the history of an alarm even if you delete the alarm.

    Args:
        alarm_name(str, optional): The name of the alarm. Defaults to None.
        alarm_types(List, optional): Use this parameter to specify whether you want the operation to return metric alarms or composite alarms. If you omit this parameter, only metric alarms are returned. Defaults to None.
        history_item_type(str, optional): The type of alarm histories to retrieve. Defaults to None.
        start_date(str, optional): The starting date to retrieve alarm history. Defaults to None.
        end_date(str, optional): The ending date to retrieve alarm history. Defaults to None.
        max_records(int, optional): The maximum number of alarm history records to retrieve. Defaults to None.
        next_token(str, optional): The token returned by a previous call to indicate that there is more data available. Defaults to None.
        scan_by(str, optional): Specified whether to return the newest or oldest alarm history first. Specify TimestampDescending to have the newest event history returned first, and specify TimestampAscending to have the oldest history returned first. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudwatch.alarm.history.describe(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudwatch.alarm.history.describe
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudwatch",
        operation="describe_alarm_history",
        op_kwargs={
            "AlarmName": alarm_name,
            "AlarmTypes": alarm_types,
            "HistoryItemType": history_item_type,
            "StartDate": start_date,
            "EndDate": end_date,
            "MaxRecords": max_records,
            "NextToken": next_token,
            "ScanBy": scan_by,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def delete_multiple(hub, ctx, dashboard_names: List) -> Dict:
    r"""
    **Autogenerated function**

    Deletes all dashboards that you specify. You can specify up to 100 dashboards to delete. If there is an error during this call, no dashboards are deleted.

    Args:
        dashboard_names(List): The dashboards to be deleted. This parameter is required.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudwatch.dashboard.delete_multiple(ctx, dashboard_names=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudwatch.dashboard.delete_multiple dashboard_names=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudwatch",
        operation="delete_dashboards",
        op_kwargs={"DashboardNames": dashboard_names},
    )


async def get(hub, ctx, dashboard_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Displays the details of the dashboard that you specify. To copy an existing dashboard, use GetDashboard, and then use the data returned within DashboardBody as the template for the new dashboard when you call PutDashboard to create the copy.

    Args:
        dashboard_name(str): The name of the dashboard to be described.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudwatch.dashboard.get(ctx, dashboard_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudwatch.dashboard.get dashboard_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudwatch",
        operation="get_dashboard",
        op_kwargs={"DashboardName": dashboard_name},
    )


async def list_all(
    hub, ctx, dashboard_name_prefix: str = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of the dashboards for your account. If you include DashboardNamePrefix, only those dashboards with names starting with the prefix are listed. Otherwise, all dashboards in your account are listed.   ListDashboards returns up to 1000 results on one page. If there are more than 1000 dashboards, you can call ListDashboards again and include the value you received for NextToken in the first call, to receive the next 1000 results.

    Args:
        dashboard_name_prefix(str, optional): If you specify this parameter, only the dashboards with names starting with the specified string are listed. The maximum length is 255, and valid characters are A-Z, a-z, 0-9, ".", "-", and "_". . Defaults to None.
        next_token(str, optional): The token returned by a previous call to indicate that there is more data available. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudwatch.dashboard.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudwatch.dashboard.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudwatch",
        operation="list_dashboards",
        op_kwargs={
            "DashboardNamePrefix": dashboard_name_prefix,
            "NextToken": next_token,
        },
    )


async def put(hub, ctx, dashboard_name: str, dashboard_body: str) -> Dict:
    r"""
    **Autogenerated function**

    Creates a dashboard if it does not already exist, or updates an existing dashboard. If you update a dashboard, the entire contents are replaced with what you specify here. All dashboards in your account are global, not region-specific. A simple way to create a dashboard using PutDashboard is to copy an existing dashboard. To copy an existing dashboard using the console, you can load the dashboard and then use the View/edit source command in the Actions menu to display the JSON block for that dashboard. Another way to copy a dashboard is to use GetDashboard, and then use the data returned within DashboardBody as the template for the new dashboard when you call PutDashboard. When you create a dashboard with PutDashboard, a good practice is to add a text widget at the top of the dashboard with a message that the dashboard was created by script and should not be changed in the console. This message could also point console users to the location of the DashboardBody script or the CloudFormation template used to create the dashboard.

    Args:
        dashboard_name(str): The name of the dashboard. If a dashboard with this name already exists, this call modifies that dashboard, replacing its current contents. Otherwise, a new dashboard is created. The maximum length is 255, and valid characters are A-Z, a-z, 0-9, "-", and "_". This parameter is required.
        dashboard_body(str): The detailed information about the dashboard in JSON format, including the widgets to include and their location on the dashboard. This parameter is required. For more information about the syntax, see Dashboard Body Structure and Syntax.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudwatch.dashboard.put(
                ctx, dashboard_name=value, dashboard_body=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudwatch.dashboard.put dashboard_name=value, dashboard_body=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudwatch",
        operation="put_dashboard",
        op_kwargs={"DashboardName": dashboard_name, "DashboardBody": dashboard_body},
    )
